@@ -97,8 +97,11 @@ def extract_text_from_pdf(filename, language="eng"):
             os.remove(extracted_image)
             if extracted_text_list is not None:
                 extracted_text = "".join(extracted_text_list.pages)
+#               custom addition
+                print(f"Page {i+1} of {pdf_reader.numPages} processed successfully.")
             else:
                 extracted_text = ""
+                print(f"Page {i+1} of {pdf_reader.numPages} processed with no text recognized.")
             embedded_text = "" + page.extractText()
             if len(embedded_text) > len(extracted_text):
                 selected_text = embedded_text
@@ -125,12 +128,15 @@ def extract_text_from_image(filename, auto_rotate=False, language="eng"):
                 return None
             result = extract_text_from_image(filename, auto_rotate=False, language=language)
             os.remove(rotated_image)
-            text = result.pages[0]
+            if result is not None:
+                text = result.pages[0]
+            else:
+                return None
         # 10 or fewer characters is probably just garbage
         if len(text.strip()) > 10:
             return FileOcrResult([text.strip()])
         else:
-            return FileOcrResult(None)
+            return None
     except TesseractError as e:
         print(f"TesseractError {e.message}")
         return None
